/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'basicstyles', 'bg', {
	bold: 'Удебелен',
	italic: 'Наклонен',
	strike: 'Зачертан текст',
	subscript: 'Долен индекс',
	superscript: 'Горен индекс',
	underline: 'Подчертан'
} );
